==> optaplanner-persistence-jaxb-7.36.1.Final-test-sources.jar: org/optaplanner/persistence/jaxb/api/score/buildin/simpledouble/SimpleDoubleScoreJaxbXmlAdapterTest.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.optaplanner.persistence.jaxb.api.score.buildin.simpledouble;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

import org.junit.Test;
import org.optaplanner.core.api.score.buildin.simpledouble.SimpleDoubleScore;
import org.optaplanner.persistence.jaxb.api.score.AbstractScoreJaxbXmlAdapterTest;

public class SimpleDoubleScoreJaxbXmlAdapterTest extends AbstractScoreJaxbXmlAdapterTest {

    @Test
    public void serializeAndDeserialize() {
        assertSerializeAndDeserialize(null, new TestSimpleDoubleScoreWrapper(null));

        SimpleDoubleScore score = SimpleDoubleScore.of(1234.4321);
        assertSerializeAndDeserialize(score, new TestSimpleDoubleScoreWrapper(score));

        score = SimpleDoubleScore.ofUninitialized(-7, 1234.4321);
        assertSerializeAndDeserialize(score, new TestSimpleDoubleScoreWrapper(score));
    }

    @XmlRootElement
    public static class TestSimpleDoubleScoreWrapper extends TestScoreWrapper<SimpleDoubleScore> {

        @XmlJavaTypeAdapter(SimpleDoubleScoreJaxbXmlAdapter.class)
        private SimpleDoubleScore score;

        @SuppressWarnings("unused")
        private TestSimpleDoubleScoreWrapper() {
        }

        public TestSimpleDoubleScoreWrapper(SimpleDoubleScore score) {
            this.score = score;
        }

        @Override
        public SimpleDoubleScore getScore() {
            return score;
        }

    }

}

==> optaplanner-persistence-jaxb-7.38.0.Final-test-sources.jar: org/optaplanner/persistence/jaxb/api/score/buildin/simpledouble/SimpleDoubleScoreJaxbXmlAdapterTest.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.optaplanner.persistence.jaxb.api.score.buildin.simpledouble;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

import org.junit.jupiter.api.Test;
import org.optaplanner.core.api.score.buildin.simpledouble.SimpleDoubleScore;
import org.optaplanner.persistence.jaxb.api.score.AbstractScoreJaxbXmlAdapterTest;

public class SimpleDoubleScoreJaxbXmlAdapterTest extends AbstractScoreJaxbXmlAdapterTest {

    @Test
    public void serializeAndDeserialize() {
        assertSerializeAndDeserialize(null, new TestSimpleDoubleScoreWrapper(null));

        SimpleDoubleScore score = SimpleDoubleScore.of(1234.4321);
        assertSerializeAndDeserialize(score, new TestSimpleDoubleScoreWrapper(score));

        score = SimpleDoubleScore.ofUninitialized(-7, 1234.4321);
        assertSerializeAndDeserialize(score, new TestSimpleDoubleScoreWrapper(score));
    }

    @XmlRootElement
    public static class TestSimpleDoubleScoreWrapper extends TestScoreWrapper<SimpleDoubleScore> {

        @XmlJavaTypeAdapter(SimpleDoubleScoreJaxbXmlAdapter.class)
        private SimpleDoubleScore score;

        @SuppressWarnings("unused")
        private TestSimpleDoubleScoreWrapper() {
        }

        public TestSimpleDoubleScoreWrapper(SimpleDoubleScore score) {
            this.score = score;
        }

        @Override
        public SimpleDoubleScore getScore() {
            return score;
        }

    }

}
